@@ -19,24 +19,17 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
-
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-#include <string.h>
-
 #include "gui_utils.h"
 #include "about.h"
 #include "main.h"
 #include "test.h"
 #include "prefs.h"
 #include "stats.h"
-#include "stock_icons.h"
 #include "chart.h"
 #include "i18n.h"
 #include "options.h"
-
 #include "graphics.h"
+#include "stock_icons.h"
 
 /*--------------------------------------------------------------------*/
 
@@ -104,7 +97,7 @@ static gchar buffer[BUFFER_SIZE];
 
     if (appGUI->tst->test_state == FALSE) return;
     
-    g_snprintf (buffer, BUFFER_SIZE, "<big><tt><b>%02d:%02d</b></tt></big>", 
+    g_snprintf (buffer, BUFFER_SIZE, "<span font_desc='16'><tt>%02d:%02d</tt></span>", 
                 appGUI->time_counter / 60, appGUI->time_counter % 60);
     gtk_label_set_markup (GTK_LABEL (appGUI->timer_label), buffer);
 }
@@ -144,7 +137,7 @@ start_test_cb (GtkWidget *widget, gpointer user_data) {
     gui_set_progress (appGUI);
 
     appGUI->time_counter = 0;
-    gtk_label_set_markup (GTK_LABEL (appGUI->timer_label), "<big><tt><b>00:00</b></tt></big>");
+    gtk_label_set_markup (GTK_LABEL (appGUI->timer_label), "<span font_desc='16'><tt>00:00</tt></span>");
 }
 
 /*--------------------------------------------------------------------*/
@@ -252,7 +245,7 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
             g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='80' face='%s' color='%s'>%s</span>",
                         config.kana_font_face,
                         config.kana_color,
-                        get_kana_sign(number, HIRAGANA));
+                        get_kana_sign(number, HIRAGANA, TRUE));
             appGUI->old_kana_type = HIRAGANA;
             break;
         case KATAKANA:
@@ -262,7 +255,7 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
             g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='80' face='%s' color='%s'>%s</span>",
                         config.kana_font_face,
                         config.kana_color,
-                        get_kana_sign(number, KATAKANA));
+                        get_kana_sign(number, KATAKANA, TRUE));
             appGUI->old_kana_type = KATAKANA;
             break;
         case ROMAJI:
@@ -270,14 +263,14 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
                 number -= MIXED_SEPARATOR;
             }
 
-            g_snprintf (letbuf, BUFFER_SIZE, "%s", get_kana_sign(number, ROMAJI));
+            g_snprintf (letbuf, BUFFER_SIZE, "%s", get_kana_sign(number, ROMAJI, TRUE));
 
             if (appGUI->old_kana_type == HIRAGANA) {
                 g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='60' face='%s' color='%s'>%s</span>"
                                                  "<span font_desc='40' face='%s' color='%s'>(%s)</span>",
                                                  config.kana_font_face,
                                                  config.kana_color,
-                                                 get_kana_sign(number, HIRAGANA),
+                                                 get_kana_sign(number, HIRAGANA, TRUE),
                                                  config.kana_font_face,
                                                  config.romaji_color,
                                                  letbuf);
@@ -286,7 +279,7 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
                                                  "<span font_desc='40' face='%s' color='%s'>(%s)</span>",
                                                  config.kana_font_face,
                                                  config.kana_color,
-                                                 get_kana_sign(number, KATAKANA),
+                                                 get_kana_sign(number, KATAKANA, TRUE),
                                                  config.kana_font_face,
                                                  config.romaji_color,
                                                  letbuf);
@@ -294,7 +287,7 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
                 g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='80' face='%s' color='%s'>%s</span>",
                                                  config.kana_font_face,
                                                  config.romaji_color,
-                                                 get_kana_sign(number, ROMAJI));
+                                                 get_kana_sign(number, ROMAJI, TRUE));
             }
             break;
         case MIXED:
@@ -302,13 +295,13 @@ gchar tmpbuf[BUFFER_SIZE], letbuf[BUFFER_SIZE];
                 g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='80' face='%s' color='%s'>%s</span>",
                                                  config.kana_font_face,
                                                  config.kana_color,
-                                                 get_kana_sign((number-MIXED_SEPARATOR), KATAKANA));
+                                                 get_kana_sign((number-MIXED_SEPARATOR), KATAKANA, TRUE));
                 appGUI->old_kana_type = KATAKANA;
             } else {
                 g_snprintf (tmpbuf, BUFFER_SIZE, "<span font_desc='80' face='%s' color='%s'>%s</span>",
                                                  config.kana_font_face,
                                                  config.kana_color,
-                                                 get_kana_sign(number, HIRAGANA));
+                                                 get_kana_sign(number, HIRAGANA, TRUE));
                 appGUI->old_kana_type = HIRAGANA;
             }
             break;
@@ -445,8 +438,6 @@ GtkWidget       *alignment;
 gint            i;
 gchar           buffer[BUFFER_SIZE];
 
-    appGUI->tooltips = gtk_tooltips_new();
-
     kanatest_register_stock_icons ();
 
     appGUI->main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -576,7 +567,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_widget_show (appGUI->stat_button);
     gtk_box_pack_start (GTK_BOX (hbox2), appGUI->stat_button, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->stat_button), 2);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->stat_button, _("Statistics"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->stat_button, _("Statistics"));
 
     appGUI->chart_button = gui_stock_label_button(NULL, KANATEST_STOCK_BUTTON_CHART);
     GTK_WIDGET_UNSET_FLAGS (appGUI->chart_button, GTK_CAN_FOCUS);
@@ -585,7 +576,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_widget_show (appGUI->chart_button);
     gtk_box_pack_start (GTK_BOX (hbox2), appGUI->chart_button, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->chart_button), 2);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->chart_button, _("Kana chart"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->chart_button, _("Kana chart"));
 
     appGUI->prefs_button = gui_stock_label_button(NULL, KANATEST_STOCK_BUTTON_OPTIONS);
     GTK_WIDGET_UNSET_FLAGS (appGUI->prefs_button, GTK_CAN_FOCUS);
@@ -594,7 +585,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_widget_show (appGUI->prefs_button);
     gtk_box_pack_start (GTK_BOX (hbox2), appGUI->prefs_button, FALSE, FALSE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->prefs_button), 2);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->prefs_button, _("Options"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->prefs_button, _("Options"));
 
     appGUI->about_button = gui_stock_label_button(NULL, KANATEST_STOCK_BUTTON_ABOUT);
     GTK_WIDGET_UNSET_FLAGS (appGUI->about_button, GTK_CAN_FOCUS);
@@ -603,7 +594,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_widget_show (appGUI->about_button);
     gtk_box_pack_start (GTK_BOX (hbox2), appGUI->about_button, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->about_button), 2);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->about_button, _("About"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->about_button, _("About"));
 
     hbox1 = gtk_hbox_new (FALSE, 0);
     gtk_widget_show (hbox1);
@@ -676,7 +667,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->start_button);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->start_button), 4);
     GTK_WIDGET_SET_FLAGS (appGUI->start_button, GTK_CAN_DEFAULT);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->start_button, _("Press to begin testing..."), NULL);
+    gtk_widget_set_tooltip_text (appGUI->start_button, _("Press to begin testing..."));
 
     appGUI->stop_button = gui_stock_label_button(_("Stop"), GTK_STOCK_STOP);
     GTK_WIDGET_UNSET_FLAGS (appGUI->stop_button, GTK_CAN_FOCUS);
@@ -686,7 +677,7 @@ gchar           buffer[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->stop_button);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->stop_button), 4);
     GTK_WIDGET_SET_FLAGS (appGUI->stop_button, GTK_CAN_DEFAULT);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->stop_button, _("Press to stop testing..."), NULL);
+    gtk_widget_set_tooltip_text (appGUI->stop_button, _("Press to stop testing..."));
 
     appGUI->quit_button = gui_stock_label_button(_("Quit"), GTK_STOCK_QUIT);
     GTK_WIDGET_UNSET_FLAGS (appGUI->quit_button, GTK_CAN_FOCUS);
@@ -696,19 +687,13 @@ gchar           buffer[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->quit_button);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->quit_button), 4);
     GTK_WIDGET_SET_FLAGS (appGUI->quit_button, GTK_CAN_DEFAULT);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->quit_button, _("Exit!"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->quit_button, _("Exit!"));
 
     gui_disable_test (appGUI);
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->combobox_lesson), config.kana_set);
     gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->combobox_kana_mode), config.kana_mode - HIRAGANA);
 
-    if (config.enable_tooltips == TRUE) {
-        gtk_tooltips_enable (appGUI->tooltips);
-    } else {
-        gtk_tooltips_disable (appGUI->tooltips);
-    }
-
     gui_url_initialize(appGUI);
 }
 
