@@ -22,17 +22,27 @@
 #ifndef _GUI_H
 #define _GUI_H
 
-#include <gtk/gtk.h>
+#include <config.h>
+
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <math.h>
 #include <time.h>
+#include <sys/time.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+#include <glib/gstdio.h>
+#include <libxml/parser.h>
 
-#define		BUFFER_SIZE		    1024
+#define     BUFFER_SIZE         1024
 
-#define		NUMBER_OF_SIGNS		104
-#define		MIXED_SEPARATOR		1000        /* magic number for mixed mode */
-#define		ANSWER_LEN			8
-#define		KANA_SET_NAMES		15
-#define		KANA_MODE_NAMES		3
-#define		MAX_NUMBER_OF_SIGNS (NUMBER_OF_SIGNS*2)
+#define     NUMBER_OF_SIGNS     104
+#define     MIXED_SEPARATOR     1000        /* magic number for mixed mode */
+#define     ANSWER_LEN          8
+#define     KANA_SET_NAMES      15
+#define     KANA_MODE_NAMES     3
+#define     MAX_NUMBER_OF_SIGNS (NUMBER_OF_SIGNS*2)
 
 #define     ANSWER_DELIMITER    ","
 #define     MAX_RANSWERS        10
@@ -53,6 +63,9 @@ typedef struct {
     GtkWidget   *notebook;
     gint        active_tab;
 
+	GtkWidget   *graph_viewport;
+	GtkWidget   *graph_drawing_area;
+
     gint        hiragana_counters[NUMBER_OF_SIGNS];
     gint        correct_hiragana_counters[NUMBER_OF_SIGNS];
     gint        katakana_counters[NUMBER_OF_SIGNS];
@@ -77,7 +90,6 @@ typedef struct {
     GtkWidget   *rna_radio_button;
     GtkWidget   *rwa_radio_button;
     GtkWidget   *raa_radio_button;
-    GtkWidget   *enable_tooltips_button;
     GtkWidget   *example_label;
 
     GtkWidget   *kana_colorbutton;
@@ -148,8 +160,6 @@ typedef struct {
     gint            about_link_index;
     GSList          about_links_list;
 
-    GtkTooltips     *tooltips;
-
     GdkPixbuf       *icon;
     GdkPixbuf       *logo;
 
@@ -195,13 +205,12 @@ typedef struct {
 } MESSAGE;
 
 
-void			gui_create_window		(GUI *appGUI);
-void            gui_set_widgets_status  (gboolean mode, GUI *appGUI);
-void            gui_display_kana        (gint number, gint mode, GUI *appGUI);
-void            gui_set_progress        (GUI *appGUI);
-void            gui_disable_test        (GUI *appGUI);
-
-void			gui_disable_start		(void);
+void    gui_create_window       (GUI *appGUI);
+void    gui_set_widgets_status  (gboolean mode, GUI *appGUI);
+void    gui_display_kana        (gint number, gint mode, GUI *appGUI);
+void    gui_set_progress        (GUI *appGUI);
+void    gui_disable_test        (GUI *appGUI);
+void    gui_disable_start       (void);
 
 #endif /* _GUI_H */
 
