@@ -2,7 +2,7 @@
 /*
  * Kanatest
  *
- * Copyright (C) 2001 Tomasz Mka
+ * Copyright (C) 2001-2004, 2006 Tomasz Mąka <pasp@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,18 +22,13 @@
 #include <config.h>
 
 #ifndef _
-#if defined(ENABLE_NLS)
 #  include <libintl.h>
+#  include <locale.h>
 #  define _(x) gettext(x)
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
 #    define N_(String) (String)
 #  endif
-#else
-#  define N_(String) (String)
-#  define _(x) (x)
-#  define gettext(x) (x)
-#endif
 #endif
 
