@@ -2,7 +2,7 @@
 /*
  * Kanatest
  *
- * Copyright (C) 2001-2004, 2006 Tomasz Mka <pasp@users.sourceforge.net>
+ * Copyright (C) 2001-2004, 2006 Tomasz Maka <pasp@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,12 @@ typedef enum {
     STAT
 } tmode;
 
+enum {
+  REPEAT_NONE = 0,
+  REPEAT_WRONG = 1, /* to ensure compatability with old stats */
+  REPEAT_ALL
+};
+
 #endif /* _MAIN_H */
 
 
