@@ -19,13 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <config.h>
-
-#include <string.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-
+#include "gui.h"
 #include "i18n.h"
 #include "gui_utils.h"
 #include "chart.h"
@@ -34,7 +28,6 @@
 #include "prefs.h"
 #include "options.h"
 
-
 /*--------------------------------------------------------------------*/
 
 void
@@ -89,14 +82,6 @@ options_repeat_mode_changed_cb (GtkToggleButton *button, gpointer user_data) {
 
 /*--------------------------------------------------------------------*/
 
-void
-options_tooltips_changed_cb (GtkToggleButton *button, gpointer user_data) {
-
-    config.enable_tooltips = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(button));
-}
-
-/*--------------------------------------------------------------------*/
-
 gint
 update_selected_kanas(GUI *appGUI) {
 
@@ -173,18 +158,12 @@ GdkColor color;
         g_snprintf (config.romaji_color, MAX_COLORNAME_LEN, "#%02X%02X%02X",
                     color.red * 256 / 65536, color.green * 256 / 65536, color.blue * 256 / 65536);
 
-        if (config.enable_tooltips == TRUE) {
-            gtk_tooltips_enable (appGUI->tooltips);
-        } else {
-            gtk_tooltips_disable (appGUI->tooltips);
-        }
-
         appGUI->opt->active_tab = gtk_notebook_get_current_page (GTK_NOTEBOOK (appGUI->opt->notebook));
 
         gdk_window_get_root_origin ((appGUI->opt->options_window)->window,
                                     &config.options_window_x, &config.options_window_y);
         gtk_widget_destroy (appGUI->opt->options_window);
-    
+
         prefs_write_config (CONFIG_FILENAME, CONFIG_DIRNAME);
     }
 }
@@ -237,10 +216,10 @@ gchar tmp[BUFFER_SIZE];
             if(get_kana_sign_mask(j, i)) {
                 if (n != 0) {
                     g_snprintf (tmp, BUFFER_SIZE, "<span font_desc='12' face='%s'>%s</span>",
-                                config.kana_font_face, get_kana_sign(pos, n));
+                                config.kana_font_face, get_kana_sign(pos, n, TRUE));
                 } else {
                     g_snprintf (tmp, BUFFER_SIZE, "<span font_desc='10' face='%s'>%s</span>",
-                                config.kana_font_face, get_kana_sign(pos, ROMAJI));
+                                config.kana_font_face, get_kana_sign(pos, ROMAJI, TRUE));
                 }
                 gtk_label_set_markup (GTK_LABEL(GTK_BIN(GTK_BUTTON(appGUI->opt->check_buttons[pos]))->child), tmp);
                 pos++;
@@ -296,7 +275,7 @@ void
 select_all_action_cb (GtkWidget *widget, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
-    kana_select_action (SELECT_ALL, appGUI);   
+    kana_select_action (SELECT_ALL, appGUI);
 }
 
 /*--------------------------------------------------------------------*/
@@ -305,7 +284,7 @@ void
 select_none_action_cb (GtkWidget *widget, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
-    kana_select_action (SELECT_NONE, appGUI);   
+    kana_select_action (SELECT_NONE, appGUI);
 }
 
 /*--------------------------------------------------------------------*/
@@ -314,7 +293,7 @@ void
 select_invert_action_cb (GtkWidget *widget, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
-    kana_select_action (SELECT_INVERT, appGUI);   
+    kana_select_action (SELECT_INVERT, appGUI);
 }
 
 /*--------------------------------------------------------------------*/
@@ -383,7 +362,7 @@ gchar buffer[BUFFER_SIZE];
     config.hiragana_mode = hiragana_mode;
 
     if (select == TRUE) {
-        kana_select_action (SELECT_NONE, appGUI);   
+        kana_select_action (SELECT_NONE, appGUI);
     }
 
     n = 0;
@@ -408,7 +387,8 @@ gchar buffer[BUFFER_SIZE];
             if (select == TRUE) {
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->check_buttons[i]), TRUE);
             } else {
-                g_snprintf (buffer, BUFFER_SIZE, "%s ", get_kana_sign(i, hiragana_mode == TRUE ? HIRAGANA:KATAKANA));
+                g_snprintf (buffer, BUFFER_SIZE, "%s ",
+							get_kana_sign(i, hiragana_mode == TRUE ? HIRAGANA:KATAKANA, TRUE));
                 gtk_text_buffer_insert (textbuffer, &iter_start, buffer, -1);
                 n++;
             }
@@ -417,7 +397,7 @@ gchar buffer[BUFFER_SIZE];
 
     if (n > 0) {
         gtk_widget_set_sensitive (appGUI->opt->select_button, TRUE);
-        g_snprintf (buffer, BUFFER_SIZE, "<i>%d %s</i>", n, _("kanas found"));
+        g_snprintf (buffer, BUFFER_SIZE, "<i>%d %s</i>", n, ngettext("kana found", "kanas found", n));
     } else {
         g_snprintf (buffer, BUFFER_SIZE, "<i>%s</i>", _("no kanas found"));
     }
@@ -453,6 +433,21 @@ auto_select_delete_event_cb (GtkWidget *widget, GdkEvent *event, gpointer user_d
 
 /*--------------------------------------------------------------------*/
 
+gint
+auto_select_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (event->keyval == GDK_Escape) {
+        auto_select_close_button_cb (widget, appGUI);
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+/*--------------------------------------------------------------------*/
+
 void
 hiragana_mode_changed_cb (GtkToggleButton *button, gpointer user_data) {
 
@@ -493,12 +488,17 @@ gchar buffer[BUFFER_SIZE];
 
     appGUI->opt->auto_selection_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (appGUI->opt->auto_selection_window), _("Statistics based selection"));
+    gtk_window_set_resizable (GTK_WINDOW (appGUI->opt->auto_selection_window), TRUE);
     gtk_window_set_transient_for (GTK_WINDOW(appGUI->opt->auto_selection_window), GTK_WINDOW(appGUI->opt->options_window));
     gtk_window_set_modal (GTK_WINDOW(appGUI->opt->auto_selection_window), TRUE);
     gtk_window_set_default_size (GTK_WINDOW(appGUI->opt->auto_selection_window), 300, 400);
+    gtk_window_move (GTK_WINDOW (appGUI->opt->auto_selection_window),
+					 config.options_window_x + 100, config.options_window_y + 80);
 
     g_signal_connect (G_OBJECT (appGUI->opt->auto_selection_window), "delete_event",
                       G_CALLBACK(auto_select_delete_event_cb), appGUI);
+    g_signal_connect (G_OBJECT(appGUI->opt->auto_selection_window), "key_press_event",
+                        G_CALLBACK(auto_select_key_press_cb), appGUI);
 
     vbox1 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox1);
@@ -563,7 +563,7 @@ gchar buffer[BUFFER_SIZE];
                       (GtkAttachOptions) 0,
                       (GtkAttachOptions) 0, 0, 0);
 
-    appGUI->opt->begin_range_spinbutton_adj = gtk_adjustment_new (config.ratio_begin, 0, 99, 1, 10, 10);
+    appGUI->opt->begin_range_spinbutton_adj = gtk_adjustment_new (config.ratio_begin, 0, 99, 1, 10, 0);
     appGUI->opt->begin_range_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->opt->begin_range_spinbutton_adj), 1, 0);
     g_signal_connect (appGUI->opt->begin_range_spinbutton, "value-changed", 
                       G_CALLBACK (spinbutton_value_changed_cb), appGUI);
@@ -591,7 +591,7 @@ gchar buffer[BUFFER_SIZE];
                       (GtkAttachOptions) 0,
                       (GtkAttachOptions) 0, 0, 0);
 
-    appGUI->opt->end_range_spinbutton_adj = gtk_adjustment_new (config.ratio_end, 1, 100, 1, 10, 10);
+    appGUI->opt->end_range_spinbutton_adj = gtk_adjustment_new (config.ratio_end, 1, 100, 1, 10, 0);
     appGUI->opt->end_range_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (appGUI->opt->end_range_spinbutton_adj), 1, 0);
     g_signal_connect (appGUI->opt->end_range_spinbutton, "value-changed", 
                       G_CALLBACK (spinbutton_value_changed_cb), appGUI);
@@ -762,7 +762,7 @@ static          MESSAGE msg2[CHART_ROWS];
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox_n), frame, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox_n), frame, FALSE, FALSE, 2);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
     g_snprintf (buffer, BUFFER_SIZE, "<b>%s:</b>", _("Drill options"));
@@ -785,8 +785,8 @@ static          MESSAGE msg2[CHART_ROWS];
     gtk_box_pack_start (GTK_BOX (vbox2),appGUI->opt->rna_radio_button, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->opt->rna_radio_button), 8);
     gtk_widget_show (appGUI->opt->rna_radio_button);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->rna_radio_button, 
-                          _("When this option is enabled the kanatest will display every question once"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->opt->rna_radio_button, 
+								 _("When this option is enabled the kanatest will display every question once"));
     g_signal_connect (G_OBJECT (appGUI->opt->rna_radio_button), "toggled",
                       G_CALLBACK (options_repeat_mode_changed_cb), appGUI);
 
@@ -795,8 +795,8 @@ static          MESSAGE msg2[CHART_ROWS];
     gtk_box_pack_start (GTK_BOX (vbox2),appGUI->opt->rwa_radio_button, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->opt->rwa_radio_button), 8);
     gtk_widget_show (appGUI->opt->rwa_radio_button);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->rwa_radio_button, 
-                          _("When this option is enabled the kanatest will repeat all wrongly answered questions at the end of test"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->opt->rwa_radio_button,
+								 _("When this option is enabled the kanatest will repeat all wrongly answered questions at the end of test"));
     g_signal_connect (G_OBJECT (appGUI->opt->rwa_radio_button), "toggled",
                       G_CALLBACK (options_repeat_mode_changed_cb), appGUI);
 
@@ -805,8 +805,8 @@ static          MESSAGE msg2[CHART_ROWS];
     gtk_box_pack_start (GTK_BOX (vbox2),appGUI->opt->raa_radio_button, TRUE, TRUE, 0);
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->opt->raa_radio_button), 8);
     gtk_widget_show (appGUI->opt->raa_radio_button);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->raa_radio_button, 
-                          _("When this option is enabled the kanatest will repeat all questions forever"), NULL);
+    gtk_widget_set_tooltip_text (appGUI->opt->raa_radio_button,
+								 _("When this option is enabled the kanatest will repeat all questions forever"));
     g_signal_connect (G_OBJECT (appGUI->opt->raa_radio_button), "toggled",
                       G_CALLBACK (options_repeat_mode_changed_cb), appGUI);
 
@@ -843,7 +843,7 @@ static          MESSAGE msg2[CHART_ROWS];
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox_n), frame, TRUE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox_n), frame, FALSE, FALSE, 2);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
     g_snprintf (buffer, BUFFER_SIZE, "<b>%s:</b>", _("Appearance"));
@@ -910,38 +910,6 @@ static          MESSAGE msg2[CHART_ROWS];
                       (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
                       (GtkAttachOptions) (0), 8, 0);
 
-    /*-----------------------------------------------------------------*/
-    /* Misc options */
-
-    frame = gtk_frame_new (NULL);
-    gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox_n), frame, TRUE, FALSE, 0);
-    gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-
-    g_snprintf (buffer, BUFFER_SIZE, "<b>%s:</b>", _("Misc options"));
-    label = gtk_label_new (buffer);
-    gtk_widget_show (label);
-    gtk_frame_set_label_widget (GTK_FRAME (frame), label);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
-    alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (frame), alignment);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
-
-    vbox2 = gtk_vbox_new (TRUE, 0);
-    gtk_widget_show (vbox2);
-    gtk_container_add (GTK_CONTAINER (alignment), vbox2);
-
-    appGUI->opt->enable_tooltips_button = gtk_check_button_new_with_label(_("Enable tooltips"));
-    gtk_container_set_border_width (GTK_CONTAINER (appGUI->opt->enable_tooltips_button), 8);
-    g_signal_connect (G_OBJECT (appGUI->opt->enable_tooltips_button), "toggled",
-                      G_CALLBACK (options_tooltips_changed_cb), NULL);
-    gtk_box_pack_start (GTK_BOX (vbox2), appGUI->opt->enable_tooltips_button, TRUE, FALSE, 0);
-    gtk_widget_show (appGUI->opt->enable_tooltips_button);
-    gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->enable_tooltips_button, 
-                          _("Toggle to enable/disable tooltips"), NULL);
-
     /*-----------------------------------------------------------------*/
     /* User-defined lesson TAB */
 
@@ -985,7 +953,7 @@ static          MESSAGE msg2[CHART_ROWS];
                 gtk_container_set_border_width (GTK_CONTAINER (frames[pos]), 2);
                 gtk_frame_set_shadow_type (GTK_FRAME (frames[pos]), GTK_SHADOW_ETCHED_OUT);
 
-                g_snprintf (buffer, BUFFER_SIZE, "%s", get_kana_sign (pos, ROMAJI));
+                g_snprintf (buffer, BUFFER_SIZE, "%s", get_kana_sign (pos, ROMAJI, TRUE));
 
                 appGUI->opt->check_buttons[pos] = gtk_check_button_new_with_mnemonic (buffer);
 
@@ -1012,8 +980,8 @@ static          MESSAGE msg2[CHART_ROWS];
 
         appGUI->opt->row_button_s[j] = gui_stock_label_button (NULL, GTK_STOCK_APPLY);
         gtk_button_set_relief (GTK_BUTTON (appGUI->opt->row_button_s[j]), GTK_RELIEF_NONE);
-        GTK_WIDGET_UNSET_FLAGS(appGUI->opt->row_button_s[j], GTK_CAN_FOCUS);
-        gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->row_button_s[j], _("Select all kanas in row"), NULL);
+        GTK_WIDGET_UNSET_FLAGS (appGUI->opt->row_button_s[j], GTK_CAN_FOCUS);
+        gtk_widget_set_tooltip_text (appGUI->opt->row_button_s[j], _("Select all kanas in row"));
         gtk_widget_show (appGUI->opt->row_button_s[j]);
         gtk_table_attach (GTK_TABLE (table), appGUI->opt->row_button_s[j], i, i+1, j, j+1,
                           (GtkAttachOptions) (GTK_FILL),
@@ -1029,7 +997,7 @@ static          MESSAGE msg2[CHART_ROWS];
         appGUI->opt->row_button_c[j] = gui_stock_label_button (NULL, GTK_STOCK_CLEAR);
         gtk_button_set_relief (GTK_BUTTON (appGUI->opt->row_button_c[j]), GTK_RELIEF_NONE);
         GTK_WIDGET_UNSET_FLAGS (appGUI->opt->row_button_c[j], GTK_CAN_FOCUS);
-        gtk_tooltips_set_tip (appGUI->tooltips, appGUI->opt->row_button_c[j], _("Deselect all kanas in row"), NULL);
+        gtk_widget_set_tooltip_text (appGUI->opt->row_button_c[j], _("Deselect all kanas in row"));
         gtk_widget_show (appGUI->opt->row_button_c[j]);
         gtk_table_attach (GTK_TABLE (table), appGUI->opt->row_button_c[j], i, i+1, j, j+1,
                           (GtkAttachOptions) (GTK_FILL),
@@ -1148,15 +1116,11 @@ static          MESSAGE msg2[CHART_ROWS];
             gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->rna_radio_button), TRUE);
     }
 
-    if (config.enable_tooltips == TRUE) {
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->opt->enable_tooltips_button), TRUE);
-    }
-
     update_selected_kanas (appGUI);
 
     if (appGUI->opt->active_tab != -1) {
         gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->opt->notebook), appGUI->opt->active_tab);
-    }  
+	}
 
     gtk_widget_show (appGUI->opt->options_window);
 
