@@ -19,9 +19,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <glib/gstdio.h>
-#include <libxml/parser.h>
-
 #include "main.h"
 #include "gui.h"
 #include "prefs.h"
@@ -34,7 +31,7 @@ gchar*
 prefs_get_config_filename (gchar *config_filename, gchar *config_dirname) {
 
 static gchar filename[PATH_MAX];
-gchar dirname[PATH_MAX]; 
+gchar dirname[PATH_MAX];
 
     g_snprintf (dirname, PATH_MAX, "%s%c%s", g_get_home_dir(), G_DIR_SEPARATOR, config_dirname);
 
@@ -60,7 +57,6 @@ prefs_set_default_values (void) {
     config.kana_mode = HIRAGANA;
     config.kana_set = 0;            /* all kanas */
     config.ca_timeout = 1;          /* 1 sec */
-    config.enable_tooltips = TRUE;
     config.stat_window_x = 45;
     config.stat_window_y = 120;
     config.stat_size_x = 760;
@@ -79,7 +75,7 @@ prefs_set_default_values (void) {
     g_strlcpy (config.kana_font_face, "Serif", MAX_FONTNAME_LEN);
     g_strlcpy (config.kana_color, "#000000", MAX_COLORNAME_LEN);
     g_strlcpy (config.romaji_color, "#BB1010", MAX_COLORNAME_LEN);
-    g_strlcpy (config.user_defined_lesson, 
+    g_strlcpy (config.user_defined_lesson,
                "+++++----------------------------------------------------------------------------------------------------", NUMBER_OF_SIGNS);
 }
 
@@ -174,13 +170,6 @@ xmlChar *key;
                     xmlFree (key);
                 }
 
-                if ((!xmlStrcmp (node->name, (const xmlChar *) "enable_tooltips"))) {
-                    key = xmlNodeListGetString (doc, node->xmlChildrenNode, 1);
-                    if (key != NULL)
-                            sscanf ((gchar *) key, "%d", &config.enable_tooltips);
-                    xmlFree (key);
-                }
-
                 if ((!xmlStrcmp (node->name, (const xmlChar *) "stat_window_x"))) {
                     key = xmlNodeListGetString (doc, node->xmlChildrenNode, 1);
                     if (key != NULL)
@@ -358,8 +347,6 @@ gchar temp[BUFFER_SIZE];
     xmlNewTextChild (node, NULL, (const xmlChar *) "kana_set", (xmlChar *) temp);
     g_snprintf (temp, BUFFER_SIZE, "%d", config.ca_timeout);
     xmlNewTextChild (node, NULL, (const xmlChar *) "ca_timeout", (xmlChar *) temp);
-    g_snprintf (temp, BUFFER_SIZE, "%d", config.enable_tooltips);
-    xmlNewTextChild (node, NULL, (const xmlChar *) "enable_tooltips", (xmlChar *) temp);
     g_snprintf (temp, BUFFER_SIZE, "%d", config.stat_window_x);
     xmlNewTextChild (node, NULL, (const xmlChar *) "stat_window_x", (xmlChar *) temp);
     g_snprintf (temp, BUFFER_SIZE, "%d", config.stat_window_y);
