@@ -22,8 +22,6 @@
 #ifndef _PREFS_H
 #define _PREFS_H
 
-#include <gtk/gtk.h>
-
 #define CONFIG_DIRNAME      ".kanatest"
 #define CONFIG_DIRNAME_OLD  ".clay"
 #define CONFIG_FILENAME     "config.xml"
@@ -44,7 +42,6 @@ struct kanatest_prefs
     gint        kana_mode;
     gint        kana_set;
     gint        ca_timeout;
-    gint        enable_tooltips;
     gint        stat_window_x;
     gint        stat_window_y;
     gint        stat_size_x;
