@@ -19,13 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <config.h>
-
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-#include <libxml/parser.h>
-
+#include "gui.h"
 #include "i18n.h"
 #include "gui_utils.h"
 #include "main.h"
@@ -34,7 +28,6 @@
 #include "prefs.h"
 #include "stats.h"
 
-
 /*--------------------------------------------------------------------*/
 
 void
@@ -169,12 +162,190 @@ stats_column_clicked_cb (GtkTreeViewColumn *treeviewcolumn, gpointer user_data)
 
 /*--------------------------------------------------------------------*/
 
+void
+draw_statistics_graph (GUI *appGUI) {
+
+gint width, height, i, k;
+cairo_t *sts_cr = NULL;
+double minY, maxY, hiragana_value, katakana_value, r;
+double h_real_y_pos, k_real_y_pos, region, stepX, stepY;
+double dash[] = { 1.0 };
+gchar buffer[BUFFER_SIZE];
+
+	width = appGUI->sts->graph_viewport->allocation.width - 4;
+	height = appGUI->sts->graph_viewport->allocation.height - 4;
+
+    sts_cr = gdk_cairo_create (appGUI->sts->graph_drawing_area->window);
+
+    cairo_set_source_rgb (sts_cr, 1.0, 1.0, 1.0);   /* white background */
+    cairo_paint (sts_cr);
+
+    cairo_set_line_width (sts_cr, 1.0);
+	cairo_set_antialias (sts_cr, CAIRO_ANTIALIAS_DEFAULT);
+
+	cairo_select_font_face (sts_cr, "Sans", CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
+	cairo_set_font_size (sts_cr, LEGEND_FONT_SIZE);
+
+	cairo_set_source_rgb (sts_cr, 0.0, 0.0, 0.0);   /* black */
+
+	/* arrows and scale */
+
+	minY = height-Y_AXIS_MARGIN - Y_BORDER;
+	maxY = height / 50.0 + ARROW_L * 2.5;
+	region = fabs(minY - maxY);
+	stepY = region / 4.0;
+
+	/* scale */
+	cairo_move_to (sts_cr, X_BORDER*1.5, minY);
+	cairo_show_text (sts_cr, "0%");
+
+	for (i=0; i < 4; i++) {
+	
+		cairo_set_source_rgb (sts_cr, 0.0, 0.0, 0.0);   /* black */
+
+		g_snprintf (buffer, BUFFER_SIZE, "%d%%", 100/4 * (i+1));
+		cairo_move_to (sts_cr, X_BORDER*1.5, minY+LEGEND_FONT_SIZE/2 - stepY*(i+1));
+		cairo_show_text (sts_cr, buffer);
+
+		cairo_set_dash (sts_cr, NULL, 0, 0);
+		cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER-TICK_WIDTH/2, minY - stepY*(i+1));
+		cairo_line_to (sts_cr, X_AXIS_MARGIN+X_BORDER+TICK_WIDTH/2, minY - stepY*(i+1));
+		cairo_stroke (sts_cr);
+
+		cairo_set_source_rgb (sts_cr, 0.7, 0.7, 0.7);   /* gray */
+		cairo_set_dash (sts_cr, dash, 1, 0);
+		cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER, minY - stepY*(i+1));
+		cairo_line_to (sts_cr, width-X_AXIS_MARGIN, minY - stepY*(i+1));
+
+		cairo_stroke (sts_cr);
+	}
+
+	/* draw graph */
+
+	if (width < height) {       /* radius for a point */
+		r = 5 * ((double)width / height);
+	} else {
+		r = 5 * ((double)height / width);
+	}
+
+	/* hiragana */
+
+	cairo_set_dash (sts_cr, NULL, 0, 0);
+
+	stepX = (width - X_AXIS_MARGIN) / NUMBER_OF_SIGNS;
+
+	for (i = 0; i < NUMBER_OF_SIGNS; i++) {
+
+		if (appGUI->sts->hiragana_counters[i] > 0) {
+			hiragana_value = ((double)appGUI->sts->correct_hiragana_counters[i]/appGUI->sts->hiragana_counters[i])*100.0;
+		} else {
+			hiragana_value = 0;
+		}
+
+		h_real_y_pos = minY - region * hiragana_value / 100.0;
+
+		if (appGUI->sts->katakana_counters[i] > 0) {
+			katakana_value = ((double)appGUI->sts->correct_katakana_counters[i]/appGUI->sts->katakana_counters[i])*100.0;
+		} else {
+			katakana_value = 0;
+		}
+
+		k_real_y_pos = minY - region * katakana_value / 100.0;
+
+		cairo_set_source_rgb (sts_cr, 0.9, 0.4, 0.0);
+		cairo_rectangle (sts_cr, X_AXIS_MARGIN+X_BORDER+stepX*i, h_real_y_pos, 
+						 stepX/2, (region * hiragana_value / 100.0));
+		cairo_fill (sts_cr);
+
+		cairo_set_source_rgb (sts_cr, 0.4, 0.0, 0.7);
+		cairo_rectangle (sts_cr, X_AXIS_MARGIN+X_BORDER+stepX*i+stepX/2, k_real_y_pos, 
+						 stepX/2, (region * katakana_value / 100.0));
+		cairo_fill (sts_cr);
+
+	}
+
+	k = 0;
+
+	cairo_set_source_rgb (sts_cr, 0.0, 0.0, 0.0);   /* black */
+
+	for (i = 0; i < NUMBER_OF_SIGNS; i++) {
+		cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER+stepX*i, minY+LEGEND_FONT_SIZE*(k+1));
+        g_snprintf (buffer, BUFFER_SIZE, "%s", get_kana_sign (i, ROMAJI, FALSE));
+	    if (buffer[2] == ',') buffer[2] = '\0';  /* special case: di,ji */
+		cairo_show_text (sts_cr, buffer);
+		k = (k + 1) % 3;
+	}
+
+	/* legend */
+
+	cairo_set_source_rgb (sts_cr, 0.9, 0.4, 0.0);
+	cairo_rectangle (sts_cr, X_AXIS_MARGIN+X_BORDER+width/1.5, 15, 8*LEGEND_FONT_SIZE, 2*LEGEND_FONT_SIZE);
+	cairo_fill (sts_cr);
+	cairo_set_source_rgb (sts_cr, 0.4, 0.0, 0.7);
+	cairo_rectangle (sts_cr, X_AXIS_MARGIN+X_BORDER+width/1.3, 15, 8*LEGEND_FONT_SIZE, 2*LEGEND_FONT_SIZE);
+	cairo_fill (sts_cr);
+	cairo_set_source_rgb (sts_cr, 1.0, 1.0, 1.0);   /* white */
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER+width/1.5+2, 25+2);
+	cairo_show_text (sts_cr, "Hiragana");
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER+width/1.3+2, 25+2);
+	cairo_show_text (sts_cr, "Katakana");
+
+	/* vertical axis */
+	cairo_set_source_rgb (sts_cr, 0.0, 0.0, 0.0);   /* black */
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER, height-Y_AXIS_MARGIN-Y_BORDER);
+    cairo_line_to (sts_cr, X_AXIS_MARGIN+X_BORDER, Y_AXIS_MARGIN);
+
+	/* arrow */
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER, Y_AXIS_MARGIN);
+    cairo_line_to (sts_cr, X_AXIS_MARGIN+X_BORDER-ARROW_A, Y_AXIS_MARGIN+ARROW_L);
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER, Y_AXIS_MARGIN);
+    cairo_line_to (sts_cr, X_AXIS_MARGIN+X_BORDER+ARROW_A, Y_AXIS_MARGIN+ARROW_L);
+
+	/* horizontal axis */
+	cairo_move_to (sts_cr, X_AXIS_MARGIN+X_BORDER, height-Y_AXIS_MARGIN-Y_BORDER);
+    cairo_line_to (sts_cr, width-X_BORDER, height-Y_AXIS_MARGIN-Y_BORDER);
+
+	/* arrow */
+	cairo_move_to (sts_cr, width-X_BORDER, height-Y_AXIS_MARGIN-Y_BORDER);
+    cairo_line_to (sts_cr, width-X_BORDER-ARROW_L, height-Y_AXIS_MARGIN-Y_BORDER-ARROW_A);
+	cairo_move_to (sts_cr, width-X_BORDER, height-Y_AXIS_MARGIN-Y_BORDER);
+    cairo_line_to (sts_cr, width-X_BORDER-ARROW_L, height-Y_AXIS_MARGIN-Y_BORDER+ARROW_A);
+
+	cairo_stroke (sts_cr);
+
+	/* destroy surface */
+
+    cairo_destroy (sts_cr);
+}
+
+/*--------------------------------------------------------------------*/
+
+gint
+graph_configure_event (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+	draw_statistics_graph (appGUI);
+	return TRUE;
+}
+
+gint
+graph_expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+	draw_statistics_graph (appGUI);
+	return FALSE;
+}
+
+/*--------------------------------------------------------------------*/
+
 void
 stats_create_window (GUI *appGUI) {
 
 GtkWidget       *vbox1, *vbox2;
 GtkWidget       *vbox3, *vbox4;
-GtkWidget       *vbox5, *vbox6;
+GtkWidget       *vbox5, *vbox6, *vbox7;
 GtkWidget       *hbuttonbox;
 GtkWidget       *close_button;
 GtkWidget       *reset_button;
@@ -343,7 +514,7 @@ gchar *column_names[NUMBER_OF_COLUMNS] = {
 
                 g_snprintf (buffer, BUFFER_SIZE, "<span face='%s'>%s/%s</span>: <span color='%s'>%d/%d</span> (%.f %%)",
                             config.kana_font_face,
-                            get_kana_sign(cpos, HIRAGANA), get_kana_sign(cpos, ROMAJI), color_str, 
+                            get_kana_sign(cpos, HIRAGANA, TRUE), get_kana_sign(cpos, ROMAJI, TRUE), color_str, 
                             appGUI->sts->correct_hiragana_counters[cpos], appGUI->sts->hiragana_counters[cpos], ratio);
 
                 gtk_label_set_markup (GTK_LABEL (appGUI->chr->labels[pos]), buffer);
@@ -414,7 +585,7 @@ gchar *column_names[NUMBER_OF_COLUMNS] = {
 
                 g_snprintf (buffer, BUFFER_SIZE, "<span face='%s'>%s/%s</span>: <span color='%s'>%d/%d</span> (%.f %%)",
                             config.kana_font_face,
-                            get_kana_sign(cpos, KATAKANA), get_kana_sign(cpos, ROMAJI), color_str, 
+                            get_kana_sign(cpos, KATAKANA, TRUE), get_kana_sign(cpos, ROMAJI, TRUE), color_str, 
                             appGUI->sts->correct_katakana_counters[cpos], appGUI->sts->katakana_counters[cpos], ratio);
 
                 gtk_label_set_markup (GTK_LABEL (appGUI->chr->labels[pos]), buffer);
@@ -425,6 +596,25 @@ gchar *column_names[NUMBER_OF_COLUMNS] = {
         }
     }
 
+	/* graph */
+
+    vbox7 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox7);
+    label = gtk_label_new (_("Graph"));
+    gtk_notebook_append_page(GTK_NOTEBOOK(appGUI->sts->notebook), vbox7, label);
+
+	appGUI->sts->graph_viewport = gtk_viewport_new (NULL, NULL);
+    gtk_widget_show (appGUI->sts->graph_viewport);
+    gtk_box_pack_start (GTK_BOX (vbox7), appGUI->sts->graph_viewport, TRUE, TRUE, 0);
+	
+	appGUI->sts->graph_drawing_area = gtk_drawing_area_new();
+    gtk_widget_show (appGUI->sts->graph_drawing_area);
+	gtk_container_add (GTK_CONTAINER(appGUI->sts->graph_viewport), appGUI->sts->graph_drawing_area);
+
+	g_signal_connect (G_OBJECT(appGUI->sts->graph_drawing_area), "configure_event",
+					  G_CALLBACK(graph_configure_event), appGUI);
+	g_signal_connect (G_OBJECT(appGUI->sts->graph_drawing_area), "expose_event",
+					  G_CALLBACK(graph_expose_event), appGUI);
 
     /* buttons */
 
@@ -467,7 +657,7 @@ gchar *column_names[NUMBER_OF_COLUMNS] = {
             gtk_list_store_append (stats_store, &stats_iter);
 
             g_snprintf (buffer, BUFFER_SIZE, "%4d.%02d.%02d, %02d:%02d", entry->date_year, entry->date_month+1, 
-                        entry->date_day+1, entry->date_hour, entry->date_minute);
+                        entry->date_day, entry->date_hour, entry->date_minute);
             gtk_list_store_set (stats_store, &stats_iter, 0, buffer, -1);
 
             switch(entry->test_repeat_mode) {
@@ -572,7 +762,7 @@ get_kana_token (gint token, gint type) {
 
 static gchar temp[BUFFER_SIZE];
 
-    g_snprintf (temp, BUFFER_SIZE, "%s_%d", get_kana_sign (token, ROMAJI), type);
+    g_snprintf (temp, BUFFER_SIZE, "%s_%d", get_kana_sign (token, ROMAJI, FALSE), type);
     if (temp[2] == ',') temp[2] = '_';  /* special case: di,ji */
 
     return temp;
