@@ -19,13 +19,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-
-#include <stdlib.h>
-#include <string.h>
-
-#include <gtk/gtk.h>
-#include <config.h>
-
 #include "gui.h"
 #include "main.h"
 #include "test.h"
@@ -34,7 +27,6 @@
 #include "options.h"
 #include "i18n.h"
 
-
 /*--------------------------------------------------------------------*/
 
 gchar *
@@ -76,7 +68,7 @@ gchar *kana_set_name[] = {
 /*--------------------------------------------------------------------*/
 
 gchar *
-get_kana_sign (gint index, gint kana_type) {
+get_kana_sign (gint index, gint kana_type, gboolean translated) {
 
 /* romanji | hiragana | katakana */
 
@@ -146,7 +138,11 @@ gchar *kana_signs[] = {
 
 };
 
-    return gettext(kana_signs[3 * index + kana_type]);
+	if (translated == TRUE) {
+	    return gettext(kana_signs[3 * index + kana_type]);
+	} else {
+        return kana_signs[3 * index + kana_type];
+	}
 }
 
 /*--------------------------------------------------------------------*/
@@ -348,8 +344,8 @@ gchar **r_answers;
 gint n_answ;
 
     kana_number = appGUI->tst->questions_table[appGUI->tst->question_counter] % MIXED_SEPARATOR;
-    r_answers = g_strsplit (get_kana_sign (kana_number, ROMAJI), ANSWER_DELIMITER, MAX_RANSWERS);
-	n_answ=0;
+    r_answers = g_strsplit (get_kana_sign (kana_number, ROMAJI, TRUE), ANSWER_DELIMITER, MAX_RANSWERS);
+	n_answ = 0;
 	correct_answer = FALSE;
 
     while (r_answers[n_answ]) {
@@ -413,7 +409,7 @@ gint n_answ;
                 gtk_entry_set_max_length (GTK_ENTRY(appGUI->romaji_entry), 3);
                 gtk_entry_set_text (GTK_ENTRY(appGUI->romaji_entry), tmp_a);
                 while (g_main_context_iteration (NULL, FALSE));
-    
+
                 if (appGUI->tst->test_state == FALSE) return;
             }
 
@@ -553,7 +549,7 @@ test_info(GUI *appGUI) {
 
     if (entry != NULL) {
 
-        tmm = time (NULL); 
+        tmm = time (NULL);
         timer = localtime (&tmm);
 
         entry->date_day = timer->tm_mday;
